==> modx-2.0.6-pl-ja.zip: modx-2.0.6-pl-ja/core/lexicon/ja/lexicon.inc.php <==
<?php
/**
 * Lexicon Japanese lexicon topic
 *
 * @language ja
 * @package modx
 * @subpackage lexicon
 * @author shimojo http://www.priqia.com/
 * @author yamamoto http://kyms.jp
 */
$_lang['duplicate'] = '複製';
$_lang['entry'] = '項目';
$_lang['entry_create'] = '項目を作成';
$_lang['entry_err_ae'] = 'すでに存在する項目です';
$_lang['entry_err_nf'] = '項目が見つかりません。';
$_lang['entry_err_ns'] = '項目が指定されていません。';
$_lang['entry_err_save'] = '語彙エントリーの保存中にエラーが発生しました。';
$_lang['entry_revert'] = '語彙エントリーを元に戻す';
$_lang['language'] = '言語';
$_lang['languages'] = '言語';
$_lang['last_modified'] = '最終更新日時';
$_lang['lexicon'] = '語彙トピック';
$_lang['lexicon_export'] = '語彙トピックをエクスポート';
$_lang['lexicon_export_desc'] = 'ここでは、選択した語彙トピックをファイルにエクスポートすることができます。';
$_lang['lexicon_topics'] = '語彙トピック';
$_lang['lexicon_topics_desc'] = 'ここで語彙トピックを管理することができます。';
$_lang['lexicon_import'] = '語彙トピックをインポート';
$_lang['lexicon_import_desc'] = 'You may import a file to load into a specified Lexicon Topic for a namespace. Your file must return a $_lang associative array of strings, similar to the core/lexicon files. If the topic in the namespace already exists, it will be overwritten.';
$_lang['lexicon_import_err_ns'] = 'Lexicon Topic file not specified.';
$_lang['lexicon_import_err_upload'] = 'An error occurred while trying to upload the new Lexicon Topic file. Check your web server permissions in trying to upload to the tmp directory, and validate that the file you are trying to upload is a valid file.';
$_lang['lexicon_management'] = '語彙トピックの管理';
$_lang['lexicon_management_desc'] = 'MODx管理画面で用いる言語(Lexicon・語彙)を各国語単位で管理します。原本となる語彙が/core/lexicon/ 以下にファイル形式で収録されており、この画面ではこれらの語彙の原本をDB側で上書きする管理を行なうことができます。';
$_lang['lexicon_rlfb_msg'] = 'Successfully regenerated [[+num]] strings.';
$_lang['reload_from_base'] = '全てのコアの項目を元に戻す';
$_lang['search_by_key'] = 'キーで検索:';
$_lang['topic'] = 'トピック';

==> modx-2.1.0-pl-ja.zip: modx-2.1.0-pl-ja/core/lexicon/ja/lexicon.inc.php <==
<?php
/**
 * Lexicon Japanese lexicon topic
 *
 * @language ja
 * @package modx
 * @subpackage lexicon
 * @author shimojo http://www.priqia.com/
 * @author yamamoto http://kyms.jp
 */
$_lang['duplicate'] = '複製';
$_lang['entry'] = '項目';
$_lang['entry_create'] = '項目を作成';
$_lang['entry_err_ae'] = 'すでに存在する項目です';
$_lang['entry_err_nf'] = '項目が見つかりません。';
$_lang['entry_err_ns'] = '項目が指定されていません。';
$_lang['entry_err_save'] = '語彙エントリーの保存中にエラーが発生しました。';
$_lang['entry_revert'] = '語彙エントリーを元に戻す';
$_lang['language'] = '言語';
$_lang['languages'] = '言語';
$_lang['last_modified'] = '最終更新日時';
$_lang['lexicon'] = '語彙トピック';
$_lang['lexicon_export'] = '語彙トピックをエクスポート';
$_lang['lexicon_export_desc'] = 'ここでは、選択した語彙トピックをファイルにエクスポートすることができます。';
$_lang['lexicon_topics'] = '語彙トピック';
$_lang['lexicon_topics_desc'] = 'ここで語彙トピックを管理することができます。';
$_lang['lexicon_import'] = '語彙トピックをインポート';
$_lang['lexicon_import_desc'] = 'You may import a file to load into a specified Lexicon Topic for a namespace. Your file must return a $_lang associative array of strings, similar to the core/lexicon files. If the topic in the namespace already exists, it will be overwritten.';
$_lang['lexicon_import_err_ns'] = 'Lexicon Topic file not specified.';
$_lang['lexicon_import_err_upload'] = 'An error occurred while trying to upload the new Lexicon Topic file. Check your web server permissions in trying to upload to the tmp directory, and validate that the file you are trying to upload is a valid file.';
$_lang['lexicon_management'] = '語彙トピックの管理';
$_lang['lexicon_management_desc'] = 'MODX管理画面で用いる言語(Lexicon・語彙)を各国語単位で管理します。原本となる語彙が/core/lexicon/ 以下にファイル形式で収録されており、この画面ではこれらの語彙の原本をDB側で上書きする管理を行なうことができます。';
$_lang['lexicon_rlfb_msg'] = 'Successfully regenerated [[+num]] strings.';
$_lang['reload_from_base'] = '全てのコアの項目を元に戻す';
$_lang['search_by_key'] = 'キーで検索:';
$_lang['topic'] = 'トピック';
